=========
Reference
=========

:Release: |version|
:Date: |today|

Functions
---------

.. automodule::  planarity.planarity_functions
   :members:

NetworkX Interface
------------------
.. automodule::  planarity.planarity_networkx
   :members:


Wrapper Class
-------------

.. autoclass::  planarity.PGraph

.. automethod:: ascii
